<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=sv
// ** ne pas modifier le fichier **

return [

	// A
	'access_interface_graphique' => 'Tillbaka till det kompletta grafiska gränssnittet',
	'access_mode_texte' => 'Visa det förenklade text-gränssnittet',
	'admin_debug' => 'avlusa',
	'admin_modifier_article' => 'Ändra artikeln',
	'admin_modifier_auteur' => 'Ändra författaren',
	'admin_modifier_breve' => 'Ändra nyheten',
	'admin_modifier_mot' => 'Ändra nyckelordet',
	'admin_modifier_rubrique' => 'Ändra avdelningen',
	'admin_recalculer' => 'Ladda om sidan',
	'afficher_trad' => 'Visa översättning',
	'alerte_maj_impossible' => '<b>Varning!</b> Misslyckades med att uppdatera SQL-databasen till version @version@. Det kan bero på ett åtkomstproblem med databasen. Var vänlig ta kontakt med din ISP.',
	'alerte_modif_info_concourante' => 'VARNING: Denna information har ändrats på annan plats. Det aktuella innehållet är:',
	'analyse_xml' => 'Undersök XML',
	'annuler' => 'Avbryt',
	'antispam_champ_vide' => 'Var vänlig, lämna fältet tomt',
	'articles_recents' => 'De senaste artiklarna',
	'avis_archive_incorrect' => 'Arkivfilen är inte en godkänd SPIP-fil',
	'avis_archive_invalide' => 'Arkivfilen är inte godkänd',
	'avis_attention' => 'SE UPP!',
	'avis_champ_incorrect_type_objet' => 'Ogiltigt fält-namn för objekt av typen @type@',
	'avis_colonne_inexistante' => 'Kolumnen @col@ finns inte',
	'avis_erreur' => 'Fel: se nedan\\’;',
	'avis_erreur_connexion' => 'Anslutningsfel',
	'avis_erreur_cookie' => 'cookieproblem',
	'avis_erreur_fonction_contexte' => 'Programmeringsfel. Den här funktionen borde inte bli kallad i det här sammanhanget.',
	'avis_erreur_mysql' => 'SQL-fel',
	'avis_erreur_sauvegarde' => 'Fel på säkerhetskopian (@type@ @id_objet@)!',
	'avis_erreur_visiteur' => 'Det har uppstått ett problem med att gå in i den privata delen',

	// B
	'barre_a_accent_grave' => 'Skapa ett stort A med bakåtvänd accent',
	'barre_aide' => 'Använd de typografiska genvägarna för att förbättra din layout',
	'barre_e_accent_aigu' => 'Skapa ett stort E med framåtvänd accent',
	'barre_eo' => 'Skapa en gemen oe-ligatur',
	'barre_eo_maj' => 'Skapa en versal EO-ligature',
	'barre_euro' => 'Skapa € symbolen',
	'barre_gras' => 'Sätt i {{fet}} stil',
	'barre_guillemets' => 'Placera mellan "dubbla citationstecken"',
	'barre_guillemets_simples' => 'Placera mellan ‘enkla citationstecken’',
	'barre_intertitre' => 'Gör till en {{{underrubrik}}}',
	'barre_italic' => 'Sätt i {kursiv} stil',
	'barre_lien' => 'Gör till en [länk->http://...]',
	'barre_lien_input' => 'Var god och ange målet för din länk (du kan ange en internet-adress så som http://www.example.com eller helt enkelt numret på en artikel på den här sajten).',
	'barre_note' => 'Gör till en [[Fotnot]]',
	'barre_paragraphe' => 'skapa ett stycke',
	'barre_quote' => '<quote>Citera ett meddelande</quote>',
	'bouton_changer' => 'Ändra',
	'bouton_chercher' => 'Sök',
	'bouton_choisir' => 'Välj',
	'bouton_download' => 'Ladda hem', # MODIF
	'bouton_enregistrer' => 'Spara',
	'bouton_radio_desactiver_messagerie_interne' => 'Stäng av möjligheten med interna meddelanden',
	'bouton_radio_envoi_annonces' => 'Skicka redaktionella tillkännagivanden',
	'bouton_radio_non_envoi_annonces' => 'Skicka inga tillkännagivanden',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Skicka inte en lista med senaste nyheter',
	'bouton_recharger_page' => 'ladda om sidan',
	'bouton_telecharger' => 'Ladda upp',
	'bouton_upload' => 'Ladda upp', # MODIF
	'bouton_valider' => 'Spara',

	// C
	'cal_apresmidi' => 'eftermiddag (e.m)',
	'cal_jour_entier' => 'hel dag',
	'cal_matin' => 'förmiddag (f.m)',
	'cal_par_jour' => 'daglig kalendar',
	'cal_par_mois' => 'månadsvis kalender',
	'cal_par_semaine' => 'veckovis kalender',
	'choix_couleur_interface' => 'Färg',
	'choix_interface' => 'val av gränssnitt',
	'colonne' => 'Kolumn',
	'confirm_changer_statut' => 'Krav på bekräftelse: Du har bett om att ändra statusen på den här artikeln. Vill du fortsätta?',
	'correcte' => 'rätt',

	// D
	'date_aujourdhui' => 'idag',
	'date_avant_jc' => 'f.Kr.',
	'date_dans' => 'om @delai@',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@j@ @nommois@',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@j@ @nommois@',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'imorgon',
	'date_fmt_heures_minutes' => '@h@:@m@',
	'date_fmt_jour_heure' => '@jour@ klockan @heure@',
	'date_fmt_jour_mois' => '@jourmois@',
	'date_fmt_jour_mois_annee' => '@jour@-@nommois@-@annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour_date' => 'på @nomjour@, @date@',
	'date_heures' => 'timmar',
	'date_hier' => 'igår',
	'date_il_y_a' => '@delai@ sen',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'söndag',
	'date_jour_1_abbr' => 'sö',
	'date_jour_1_initiale' => 's',
	'date_jour_2' => 'måndag',
	'date_jour_2_abbr' => 'må',
	'date_jour_2_initiale' => 'm',
	'date_jour_3' => 'tisdag',
	'date_jour_3_abbr' => 'ti',
	'date_jour_3_initiale' => 't',
	'date_jour_4' => 'onsdag',
	'date_jour_4_abbr' => 'on',
	'date_jour_4_initiale' => 'o',
	'date_jour_5' => 'torsdag',
	'date_jour_5_abbr' => 'to',
	'date_jour_5_initiale' => 't',
	'date_jour_6' => 'fredag',
	'date_jour_6_abbr' => 'fr',
	'date_jour_6_initiale' => 'f',
	'date_jour_7' => 'lördag',
	'date_jour_7_abbr' => 'lö',
	'date_jour_7_initiale' => 's',
	'date_jours' => 'dagar',
	'date_minutes' => 'minuter',
	'date_mois' => 'månader',
	'date_mois_1' => 'Januari',
	'date_mois_10' => 'Oktober',
	'date_mois_11' => 'November',
	'date_mois_12' => 'December',
	'date_mois_2' => 'Februari',
	'date_mois_3' => 'Mars',
	'date_mois_4' => 'April',
	'date_mois_5' => 'Maj',
	'date_mois_6' => 'Juni',
	'date_mois_7' => 'Juli',
	'date_mois_8' => 'Augusti',
	'date_mois_9' => 'September',
	'date_saison_1' => 'vinter',
	'date_saison_2' => 'vår',
	'date_saison_3' => 'sommar',
	'date_saison_4' => 'höst',
	'date_secondes' => 'sekunder',
	'date_semaines' => 'veckor',
	'date_un_mois' => 'månad',
	'date_une_heure' => 'timme',
	'date_une_minute' => 'minut',
	'date_une_seconde' => 'sekund',
	'date_une_semaine' => 'vecka',
	'dirs_commencer' => ' för att verkligen kunna påbörja installationen',
	'dirs_preliminaire' => 'Preliminärt: <b>Ställer in rättigheterna</b>',
	'dirs_probleme_droits' => 'Problem med åtkomst-rättigheter',
	'dirs_repertoires_absents' => '<b>Följande kataloger har inte hittats: <ul>@bad_dirs@.</ul> </b><p>Det beror antagligen på dåligt användande av gemena och VERSALER i namngivandet. Var god kontrollera att de gemena och VERSALA bokstäverna i namnet på katalogerna motsvarar det som visas ovan; om så inte är fallet, ändra namnen med hjälp av dini FTP-klient för att åtgärda felet.</p><p>När det är gjort, kan du ',
	'dirs_repertoires_suivants' => '<b>Följande kataloger saknar skriv-rättigheter: <ul>@bad_dirs@.</ul> </b><p>För att ändra det, använd din FTP-klient för att sätta korrekta åtkomsträttigheter för katalogerna. Proceduren beskrivs i installationsguiden.</p><p>När det är avklarat, kan du ',
	'double_occurrence' => 'Två exempel på @balise@',

	// E
	'en_cours' => 'arbetar',
	'envoi_via_le_site' => 'Skicka genom sajten',
	'erreur' => 'Fel',
	'erreur_balise_non_fermee' => 'Den sista tagen är inte stängd:',
	'erreur_texte' => 'fel',
	'etape' => 'Etapp',

	// F
	'fichier_introuvable' => 'Fil som inte kunde hittas: @fichier@', # MODIF
	'form_auteur_confirmation' => 'Bekräfta din e-postadress',
	'form_auteur_email_modifie' => 'Din e-postadress är nu ändrad.',
	'form_auteur_envoi_mail_confirmation' => 'En bekräftelse har skickats med e-post till @email@. Klicka på den länk som du hittar i detta meddelande för att bekräfta din e-postadress.',
	'form_auteur_mail_confirmation' => 'Hej,

du vill ändra din e-postadress.
För att bekräfta din nya adress måste du gå till
 adressen nedan. (Annars kommer adressändringen inte att genomföras.):

    @url@
',
	'form_deja_inscrit' => 'Du är redan registrerad',
	'form_email_non_valide' => 'Din epost-adress är ogiltig',
	'form_forum_access_refuse' => 'Du har inte längre tillgång till den här sajten',
	'form_forum_bonjour' => 'Hej @nom@,',
	'form_forum_email_deja_enregistre' => 'Epost-adressen är redan i bruk, du kan alltså använda ditt vanliga lösenord',
	'form_forum_identifiant_mail' => 'Dina nya användaruppgifter har precis skickats till dig med epost.',
	'form_forum_identifiants' => 'Personliga användaruppgifter',
	'form_forum_indiquer_nom_email' => 'Skriv in ditt namn och din epost-adress här så kommer du att få dina personliga användaruppgifter med epost inom kort.',
	'form_forum_login' => 'logga in:',
	'form_forum_message_auto' => '(detta är ett automatiskt meddelande)',
	'form_forum_pass' => 'lösenord:',
	'form_forum_probleme_mail' => 'Epost problem: användaruppgifterna kunde inte skickas.',
	'form_forum_voici1' => 'Här är dina användaruppgifter för att kunna kan delta i sajtens liv
"@nom_site_spip@" (@adresse_site@):',
	'form_forum_voici2' => 'Här är dina användaruppgifter för att skriva artiklar
 för sajten "@nom_site_spip@" (@adresse_login@):',
	'form_indiquer_email' => 'Var god ange in din epost-adress.',
	'form_indiquer_nom' => 'Var god ange in ditt namn.',
	'form_indiquer_nom_site' => 'Var god och ange din sajts namn',
	'form_pet_deja_enregistre' => 'Den här sajten är redan registrerad',
	'form_pet_signature_pasprise' => 'Din underskrift har ignorerats.',
	'form_prop_confirmer_envoi' => 'Bekräfta',
	'form_prop_description' => 'Beskrivning/kommentar',
	'form_prop_enregistre' => 'Ditt förslag har sparats, det kommer att visas online när det har godkänts av en administratör för denna sajt.', # MODIF
	'form_prop_envoyer' => 'Skicka ett meddelande',
	'form_prop_indiquer_email' => 'Var god och ange en giltig epost-adress',
	'form_prop_indiquer_nom_site' => 'Var god och ange sajtens namn',
	'form_prop_indiquer_sujet' => 'Var god och ange ett ämne',
	'form_prop_message_envoye' => 'Meddelandet skickat',
	'form_prop_non_enregistre' => 'Ditt förslag har inte sparats.',
	'form_prop_sujet' => 'Ämne',
	'form_prop_url_site' => 'Sajtens URL', # MODIF
	'forum_non_inscrit' => 'Antingen är du inte registrerad eller så är adressen eller lösenordet felaktigt.',
	'forum_par_auteur' => 'av @auteur@',
	'forum_titre_erreur' => 'Fel...',

	// I
	'ical_texte_rss_articles' => 'filen «backend» för artiklarna på den här sajten finns på adressen:',
	'ical_texte_rss_articles2' => 'Dessutom kan du hämta backendfiler för artiklarna i var och en av sajtens olika avdelningar:',
	'ical_texte_rss_breves' => 'Dessutom finns det en fil somo innehåller sajtenss nyheter. Genom att välja ett avdelnings-nummer, kan du få enbart de nyheter som tillhör den avdelningen.',
	'icone_a_suivre' => 'Fortsätt',
	'icone_admin_site' => 'Administrera sajten',
	'icone_agenda' => 'Kalender',
	'icone_aide_ligne' => 'Hjälp',
	'icone_articles' => 'Artiklar',
	'icone_auteurs' => 'Författare',
	'icone_brouteur' => 'Snabb-surfning',
	'icone_configuration_site' => 'Konfiguration',
	'icone_configurer_site' => 'Konfigurera din sajt',
	'icone_creer_nouvel_auteur' => 'Skapa en ny författare',
	'icone_creer_rubrique' => 'Skapa en avdelning',
	'icone_creer_sous_rubrique' => 'Skapa en underavdelning',
	'icone_deconnecter' => 'Logga ut',
	'icone_discussions' => 'Diskutioner',
	'icone_doc_rubrique' => 'Bifogade dokument',
	'icone_ecrire_article' => 'Skriv en ny artikel',
	'icone_edition_site' => 'Redigera sajten',
	'icone_gestion_langues' => 'Språk-hantering',
	'icone_informations_personnelles' => 'Personlig information',
	'icone_interface_complet' => 'Fullständigt gränssnitt',
	'icone_interface_simple' => 'Förenklat gränssnitt',
	'icone_maintenance_site' => 'Underhåll av sajten',
	'icone_messagerie_personnelle' => 'Personligt meddelandesystem',
	'icone_repartition_debut' => 'Visa fördelningen från starten',
	'icone_rubriques' => 'Avdelningar',
	'icone_sauver_site' => 'Säkerhetskopiera sajten',
	'icone_site_entier' => 'Hela sajten',
	'icone_sites_references' => 'Länkade sajter',
	'icone_statistiques' => 'Statistik för sajten',
	'icone_suivi_activite' => 'Uppföljning av sajtens aktivitet',
	'icone_suivi_actualite' => 'Statistik för sajten',
	'icone_suivi_pettions' => 'Hantera namninsamlingarna',
	'icone_suivi_revisions' => 'Förändringar i artiklar',
	'icone_supprimer_document' => 'Radera dokumentet',
	'icone_supprimer_image' => 'Radera bilden',
	'icone_tous_articles' => 'Alla dina artiklar',
	'icone_tous_auteur' => 'Alla författare',
	'icone_visiter_site' => 'Besök sajten', # MODIF
	'icone_voir_en_ligne' => 'Se online',
	'img_indisponible' => 'bilden är otillgänlig',
	'impossible' => 'omöjlig(t)',
	'info_a_suivre' => 'STARTPUNKT»',
	'info_acces_interdit' => 'Åtkomst förbjuden',
	'info_acces_refuse' => 'Åtkomst nekad',
	'info_action' => 'Åtgärd: @action@',
	'info_administrer_rubriques' => 'Du kan hantera avdelningen och dess under-avdelningar',
	'info_adresse_non_indiquee' => 'Du angav inte en adress att prova!',
	'info_aide' => 'HJÄLP:',
	'info_ajouter_mot' => 'Lägg till nyckelordet',
	'info_annonce' => 'MEDDELANDE',
	'info_annonces_generales' => 'Allmänna meddelanden:',
	'info_article_propose' => 'Sparad artikel',
	'info_article_publie' => 'Publicerad artikel',
	'info_article_redaction' => 'Artikel under bearbetning',
	'info_article_refuse' => 'Refuserad artikel',
	'info_article_supprime' => 'Raderad artikel',
	'info_articles' => 'Artiklar',
	'info_articles_a_valider' => 'Artiklar som ska godkännas',
	'info_articles_nb' => '@nb@ artiklar',
	'info_articles_proposes' => 'Sparade artiklar',
	'info_articles_un' => '1 artikel',
	'info_auteurs_nombre' => 'författare:',
	'info_authentification_ftp' => 'Authentifiering (via FTP)',
	'info_breves_2' => 'nyheter',
	'info_breves_nb' => '@nb@ nyheter',
	'info_breves_un' => '1 nyhet',
	'info_connexion_refusee' => 'Anslutning nekad',
	'info_contact_developpeur' => 'Var god och ta kontakt med en utvecklare', # MODIF
	'info_contenance' => 'Sajten innehåller:',
	'info_contribution' => 'bidrag till forumen', # MODIF
	'info_copyright' => '@spip@ är fri programvara och distribueras @lien_gpl@.',
	'info_copyright_doc' => 'För mer information, se (på engelska)<a href="@spipnet@">http://www.spip.net/en</a>.', # MODIF
	'info_copyright_gpl' => 'under GPL-licensen',
	'info_cours_edition' => 'Dina artiklar under bearbetning', # MODIF
	'info_creer_repertoire' => 'Var god och skapa en katalog som heter:',
	'info_creer_repertoire_2' => 'i under-katalogen <b>@repertoire@</b>, sedan',
	'info_creer_vignette' => 'skapa en tumnagel automatiskt ',
	'info_deplier' => 'Öppna',
	'info_descriptif_nombre' => 'beskrivning(ar):',
	'info_description' => 'Bekrivning:',
	'info_description_2' => 'Beskrivning:',
	'info_dimension' => 'Storlek:',
	'info_documents_nb' => '@nb@ dokument',
	'info_documents_un' => '1 dokument',
	'info_ecire_message_prive' => 'Skriv ett privat meddelande',
	'info_email_invalide' => 'Ogiltigt epost-adress.',
	'info_en_cours_validation' => 'Dina artiklar under arbete',
	'info_en_ligne' => 'Online nu:',
	'info_envoyer_message_prive' => 'Skicka ett privat meddelande till författaren',
	'info_erreur_requete' => 'Fel i frågan:',
	'info_erreur_squelette2' => 'Det finns ingen mall <b>@fichier@</b>...',
	'info_erreur_systeme' => 'Systemfel (errno @errsys@)',
	'info_erreur_systeme2' => 'Hårddisken kan vara full eller databasen kan vara skadad.<br />
<span style="color:red;">Försök <a href=\'@script@\'>laga databasen</a>, eller kontakta din leverantör.</span>',
	'info_fini' => 'Klart!',
	'info_format_image' => 'Bildformat som kan användas för att skapa ikoner: @gd_formats@.',
	'info_format_non_defini' => 'Odefinierat format',
	'info_grand_ecran' => 'Stor bild',
	'info_image_aide' => 'HJÄLP',
	'info_image_process_titre' => 'Hur du skapar tumnaglar',
	'info_impossible_lire_page' => '<b>Fel!</b> Sidan <tt><html>@test_proxy@</html></tt>  kan inte läsas genom proxyservern',
	'info_installation_systeme_publication' => 'Installation av publicerings-system ...',
	'info_installer_documents' => 'Du kan automatiskt installera alla dokument som finns i katalogen @upload@.',
	'info_installer_ftp' => 'Som administratör, kan du ladda upp filer (via FTP) till mappen @upload@ för att senare kunna välja dem därifrån.', # MODIF
	'info_installer_images' => 'Du kan använda bilder i formaten JPEG, GIF och PNG.',
	'info_installer_images_dossier' => 'Ladda upp biilerna i katalogen @upload@ för att senare välja dem därifrån.',
	'info_interface_complete' => 'komplett gränssnitt',
	'info_interface_simple' => 'Förenklat gränssnitt',
	'info_joindre_document_article' => 'Till din artikel kan du bifoga filer i formaten',
	'info_joindre_document_rubrique' => 'I avdelningen kan du lägga till dokument av typen',
	'info_joindre_documents_article' => 'Till din artikel kan du bifoga filer i formaten:',
	'info_l_article' => 'artikeln',
	'info_la_breve' => 'nyheten',
	'info_la_rubrique' => 'avdelningen',
	'info_langue_principale' => 'Huvud-språk för sajten',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ pixlar',
	'info_les_auteurs_1' => 'av @les_auteurs@',
	'info_logo_format_interdit' => 'Endast logotyper i formaten @formats@ är tillåtna.',
	'info_logo_max_poids' => 'Logotypen måste vara mindre än @maxi@ (Din fil är @actuel@).',
	'info_mail_fournisseur' => 'you@isp.com',
	'info_message_2' => 'MEDDELANDE',
	'info_message_supprime' => 'RADERAT MEDDELANDE',
	'info_messages_nb' => '@nb@ meddelanden',
	'info_messages_un' => '1 meddelande',
	'info_mise_en_ligne' => 'Datum för publicering online',
	'info_modification_parametres_securite' => 'uppdaterar säkerhetsinställningar',
	'info_mois_courant' => 'I månaden:',
	'info_mot_cle_ajoute' => 'Följande nyckelord las till',
	'info_multi_herit' => 'Förvalt språk',
	'info_multi_langues_soulignees' => 'För de <u>understrukna språken</u> tillhandahåller SPIP en översättning av all text i gränssnittet. Om du väljer dessa språk, kommer många delar av den publika delen (datum, formulär) att översättas automatiskt. För de språk som inte är understrukna, kommer de delarna att vara i sajtens huvudspråk.', # MODIF
	'info_multilinguisme' => 'Flerspråkig',
	'info_nom_non_utilisateurs_connectes' => 'Ditt namn visas inte i listan över anslutna användare.', # MODIF
	'info_nom_utilisateurs_connectes' => 'Ditt namn visas i listan över anslutna användare.', # MODIF
	'info_nombre_en_ligne' => 'Online nu:',
	'info_non_resultat' => 'Inga ressultat för "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Du använder inte sajtens initerna meddelande-system',
	'info_nouveau_message' => 'DU HAR ETT NYTT MEDDELANDE',
	'info_nouveaux_messages' => 'DU HAR @total_messages@ NYA MEDDELANDEN',
	'info_numero_abbreviation' => 'Nr',
	'info_obligatoire' => 'Denna information är obligatorisk',
	'info_pense_bete' => 'MEMO',
	'info_petit_ecran' => 'Liten bild',
	'info_petition_close' => 'Omröstningen stängd',
	'info_pixels' => 'pixlar',
	'info_plusieurs_mots_trouves' => 'Flear nyckelord hittades för "@cherche_mot@":',
	'info_portfolio_automatique' => 'Automatiserad portfölj',
	'info_premier_resultat' => '[@debut_limit@ första resultaten av sammanlagt @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ första resultaten av sammanlagt @total@]',
	'info_propose_1' => '[@nom_site_spip@] Skickad: @titre@',
	'info_propose_2' => 'Skickad artikel
-----------------',
	'info_propose_3' => 'Artikeln "@titre@" är skickad för publicering.',
	'info_propose_4' => 'Du har blivit inbjuden att granska och kommentera den',
	'info_propose_5' => 'i forumet kopplat till den. den är tillgänglig på adressen:',
	'info_publie_01' => 'Artikeln "@titre@" godkändes av @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBLICERADE: @titre@',
	'info_publie_2' => 'Publicerad artikel
-----------------',
	'info_rechercher' => 'Sök',
	'info_rechercher_02' => 'Sök:',
	'info_remplacer_vignette' => 'Byt ut standardikonen mot en egen ikon:',
	'info_rubriques_nb' => '@nb@ avdelningar',
	'info_rubriques_un' => '1 avdelning',
	'info_sans_titre_2' => 'utan titel',
	'info_selectionner_fichier' => 'Du kan välja en fil i foldern @upload@',
	'info_selectionner_fichier_2' => 'Välj en fil:',
	'info_sites_nb' => '@nb@ sidor',
	'info_sites_un' => '1 sida',
	'info_supprimer_vignette' => 'radera ikonen',
	'info_symbole_bleu' => 'En <b>blå</b> symbol visar ett <b>meddelande</b>: ett personligt meddelande.',
	'info_symbole_jaune' => 'En <b>gul</b> symbol visar ett <b>meddelande till alla redaktörer</b>: det kan editeras av alla administratörer, och är synligt för alla redaktörer.', # MODIF
	'info_symbole_vert' => 'En <b>grön</b> symbol visar <b>meddelanden från och till andra användare</b> på sajten.', # MODIF
	'info_telecharger_nouveau_logo' => 'Ladda upp en ny logotype:',
	'info_telecharger_ordinateur' => 'Ladda upp från din dator:',
	'info_tous_resultats_enregistres' => '[alla resultat är sparade]',
	'info_tout_afficher' => 'Visa allt',
	'info_travaux_texte' => 'Den här websidan är inte färdig. Kom gärna tilbaka senare...',
	'info_travaux_titre' => 'Sajt i uppbyggnad',
	'info_trop_resultat' => 'För många resultat för "@cherche_mot@"; försöka att avgränsa sökningen mer.',
	'info_utilisation_messagerie_interne' => 'Du använder sajtens interna meddelandesystem.',
	'info_valider_lien' => 'godkänn länken',
	'info_verifier_image' => ', kontrollera att bilderna är korrekt överförda.',
	'info_vignette_defaut' => 'Standardlogotype',
	'info_vignette_personnalisee' => 'Anpassad logotyp',
	'info_visite' => 'besök:',
	'info_vos_rendez_vous' => 'Dina framtida möten',
	'infos_vos_pense_bete' => 'Din meddelanden', # MODIF

	// L
	'lien_afficher_icones_seuls' => 'Visa bara ikoner',
	'lien_afficher_texte_icones' => 'Visa ikoner och text',
	'lien_afficher_texte_seul' => 'Visa enbart text',
	'lien_liberer' => 'version',
	'lien_liberer_tous' => 'frigör artiklarna', # MODIF
	'lien_nouvea_pense_bete' => 'Nytt memo',
	'lien_nouveau_message' => 'NYTT MEDDELANDE',
	'lien_nouvelle_annonce' => 'NYTT MEDDELANDE',
	'lien_petitions' => 'NAMNINSAMLING',
	'lien_popularite' => 'Popularitet: @popularite@%',
	'lien_racine_site' => 'Sajtens bas',
	'lien_reessayer' => 'Försök igen',
	'lien_repondre_message' => 'Svara på det här meddelandet',
	'lien_supprimer' => 'radera',
	'lien_tout_afficher' => 'Visa alla',
	'lien_visite_site' => 'Besök den här sajten',
	'lien_visites' => '@visites@ besökare',
	'lien_voir_auteur' => 'Visa redaktören',
	'ligne' => 'Rad',
	'login' => 'Förbindelse',
	'login_acces_prive' => 'Tillträde till den privata delen',
	'login_autre_identifiant' => 'använd ett annat id ID',
	'login_cookie_accepte' => 'Var vänlig, konfigurera din webbläsare så att den accepterar dem (åtminstone för den här sajten).',
	'login_cookie_oblige' => 'För att identifiera dig säkert, måste du acceptera cookies.',
	'login_deconnexion_ok' => 'Du har loggat ut.',
	'login_erreur_pass' => 'Felaktigt lösenord.',
	'login_espace_prive' => 'privat del',
	'login_identifiant_inconnu' => 'loginnamnet "@login@" är okänt.',
	'login_login' => 'Login:',
	'login_login2' => 'Login (loginnamn för sajten):', # MODIF
	'login_login_pass_incorrect' => '(fel login eller lösenord).',
	'login_motpasseoublie' => 'bortglömt lösenord?',
	'login_non_securise' => 'Varning, detta formulär är inte säkert.
   Om du inte vill skicka ditt lösenord i klartext över internet
   Var vänlig och aktivera Javasvcript
  i din webbläsare och',
	'login_nouvelle_tentative' => 'Nytt försök',
	'login_par_ici' => 'Du är registrerad... den här vägen...',
	'login_pass2' => 'Lösenord:',
	'login_preferez_refuser' => '<b>Om du inte vill använda cookies</b>, så finns det en annan uppkopplingsmetod tillgänglig (mer osäker):',
	'login_recharger' => 'ladda om sidan',
	'login_rester_identifie' => 'Kom ihåg mitt ID under några dagar', # MODIF
	'login_retour_public' => 'Tillbaka till den publika delen',
	'login_retour_site' => 'Tillbaka till den publika delen',
	'login_retoursitepublic' => 'Tillbaka till den publika delen',
	'login_securise' => 'Säker inloggning',
	'login_sinscrire' => 'registrera dig', # MODIF
	'login_test_navigateur' => 'testar webbläsare/återuppkoppling',
	'login_verifiez_navigateur' => '(Kontrollera att din webbläsare inte sparade lösenordet...)',

	// M
	'masquer_colonne' => 'Göm den här kolumnen',
	'masquer_trad' => 'göm översättningar',
	'module_fichiers_langues' => 'Språkfiler',

	// N
	'navigateur_pas_redirige' => 'Om din webbläsare inte pekas om, klicka här för att fortsätta.',
	'numero' => 'Nummer',

	// O
	'occurence' => 'Instans',
	'onglet_affacer_base' => 'Radera databasen',
	'onglet_auteur' => 'Redaktören',
	'onglet_contenu_site' => 'Sajtens innehåll',
	'onglet_evolution_visite_mod' => 'Besöksnivå',
	'onglet_fonctions_avances' => 'Avancerade inställningar',
	'onglet_informations_personnelles' => 'Personlig information',
	'onglet_interactivite' => 'Interaktivitet',
	'onglet_messagerie' => 'Meddelanden',
	'onglet_repartition_rubrique' => 'Fördelning efter avdelning',
	'onglet_save_restaur_base' => 'Backup/återställande av databas',
	'onglet_vider_cache' => 'Töm cachen',

	// P
	'pass_choix_pass' => 'Var vänlig, välj ett nytt lösenord:',
	'pass_erreur' => 'Fel',
	'pass_erreur_acces_refuse' => '<b>Fel:</b> du har inte tillträde till den här sajten längre.',
	'pass_erreur_code_inconnu' => '<b>Fel:</b> Den här identiteten finns inte bland de som har tillgång till den här sajten.', # MODIF
	'pass_erreur_non_enregistre' => '<b>Fel :</b> adressen <tt>@email_oubli@</tt> är inte registrerad på den här sajten.',
	'pass_erreur_non_valide' => '<b>Fel :</b> mejladressen <tt>@email_oubli@</tt> är inte giltig!',
	'pass_erreur_probleme_technique' => '<b>Fel :</b> mejlet kunde inte sändas på grund av ett tekniskt problem.',
	'pass_espace_prive_bla' => 'Den privata delen är öppen för besökare
efter registrering. efter att du registrerat dig,
kan du se artiklarna under redigering,
lämna in artiklar och delta i alla forum.', # MODIF
	'pass_forum_bla' => 'Du har begärt att få ta del av ett forum
som är reserverat för registrerade besökare.', # MODIF
	'pass_indiquez_cidessous' => 'Skriv in mejladressen som du använde 
vid registreringen här under
Du kommer att få ett mejl som förklarar
hur du återigen kan få tillgång.',
	'pass_mail_passcookie' => '(det här är ett automatiskt skapat meddelande)

För att återfå tillgång till sajten
@nom_site_spip@ (@adresse_site@)

var vänlig gå till följande webbadress:
    @sendcookie@

Du kan där fylla i ett nytt lösenord
och koppla upp dig mot sajten igen.
', # MODIF
	'pass_mot_oublie' => 'Bortglömt lösenord',
	'pass_nouveau_enregistre' => 'Ditt nya lösenord har sparats.',
	'pass_nouveau_pass' => 'Nytt lösenord',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Glömma bort lösenord',
	'pass_quitter_fenetre' => 'Stäng detta fönster',
	'pass_rappel_login' => 'Kom ihåg: ditt användarnamn (login) är "@login@".',
	'pass_recevoir_mail' => 'Du kommer att få ett mejl som förklarar hur du kan återfå tillgång till sajten.', # MODIF
	'pass_retour_public' => 'Tillbaka till den publika delen',
	'pass_rien_a_faire_ici' => 'Det finns inget att göra här.',
	'pass_vousinscrire' => 'Registrera dig på sajten',
	'precedent' => 'föregående',
	'previsualisation' => 'Förhandsvisning',
	'previsualiser' => 'visualisera',

	// R
	'retour' => 'Gå tillbaka',

	// S
	'spip_conforme_dtd' => 'SPIP anser att sidan stämmer med dess DOCTYPE:',
	'squelette' => 'mall',
	'squelette_inclus_ligne' => 'inkluderar mall, rad',
	'squelette_ligne' => 'mall, rad',
	'stats_visites_et_popularite' => '@visites@ besök; popularitet: @popularite@',
	'suivant' => 'nästa',

	// T
	'taille_ko' => '@taille@ kb',
	'taille_mo' => '@taille@ Mb',
	'taille_octets' => ' @taille@ bytes',
	'taille_octets_bi' => ' @taille@ bytes',
	'texte_actualite_site_1' => 'När du vant dig vid gränssnittet, klicka på «',
	'texte_actualite_site_2' => 'Fullständigt gränssnitt',
	'texte_actualite_site_3' => '» för att göra fler funktioner tillgängliga.',
	'texte_creation_automatique_vignette' => 'Automatisk generering av miniatyrer är aktiverat på den här sajten. Om du laddar upp bilder, i formaten @gd_formats@, med det här formuläret, kommer de att kopplas till en miniatyr med maximal storlek @taille_preview@ pixlar.',
	'texte_documents_associes' => 'Följande dokument är länkade till artikeln,
    men de är inte direkt bifogade
    Beroende på sajtens utseende,
    kan de uppträda som bifogade dokument.',
	'texte_erreur_mise_niveau_base' => 'Databasfel under uppgraderingen.
      Bilden <b>@fichier@</b> uppgraderades inte (artikel @id_article@).<p>
   Anteckna referensen och försök köra uppgraderingen igen,
   kontrollera efteråt att bilderna fortfarande
      finns i artiklarna.',
	'texte_erreur_visiteur' => 'Du har försökt att öppna den privata delen med  en identitet som inte har tillträde.',
	'texte_inc_auth_1' => 'Du har identifierat dig med login
  <b>@auth_login@</b>, men det finns inte i databasen (längre). 
  Försök att',
	'texte_inc_auth_2' => 'Koppla upp igen',
	'texte_inc_auth_3' => 'efter att ha stängt och sedan
  omstartat webbläsaren om nödvändigt.',
	'texte_inc_config' => 'Förändringar som du gör på denna sida påverkar starkt 
 sajtens funktion. Vi rekommenderar att du inte gör något innan du bekantat dig med funktionaliteten i SPIP. <br /><br /><b>I
 allmänhet, rekommenderas starkt
 att lämna ansvaret för dessa sidor  till sajtens huvudsakliga webbmaster. <b>',
	'texte_inc_meta_1' => 'Ett fel inträffade då systemet skrev <code>@fichier@</code>. Som administratör, var vänlig,', # MODIF
	'texte_inc_meta_2' => 'Kontrollera skrivrättigheterna',
	'texte_inc_meta_3' => 'i katalogen <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'under redaktion',
	'texte_statut_poubelle' => 'i papperskorgen',
	'texte_statut_propose_evaluation' => 'inlämnad för godkännande',
	'texte_statut_publie' => 'publicerad online',
	'texte_statut_refuse' => 'refuserad',
	'titre_ajouter_mot_cle' => 'LÄGG TILL ETT NYCKELORD:',
	'titre_cadre_raccourcis' => 'GENVÄGAR:',
	'titre_changer_couleur_interface' => 'Byter färg på gränssnittet',
	'titre_image_admin_article' => 'Du kan redigera den här artikeln',
	'titre_image_administrateur' => 'Administratör', # MODIF
	'titre_image_aide' => 'Hjälp för den här saken',
	'titre_image_auteur_supprime' => 'Redaktören raderad',
	'titre_image_redacteur' => 'Redaktör utan behörighet',
	'titre_image_redacteur_02' => 'Redaktör',
	'titre_image_visiteur' => 'Besökare',
	'titre_joindre_document' => 'BIFOGA ETT DOKUMENT',
	'titre_mots_cles' => 'NYCKELORD',
	'titre_probleme_technique' => 'OBS!: ett tekniskt problem (databasservern) förhindrar tillgång till den här delen. Tack för förståelsen.',
	'titre_publier_document' => 'PUBLICERA ETT DOKUMENT I DEN HÄR AVDELNINGEN',
	'titre_signatures_attente' => 'Bidrag i väntan på validering',
	'titre_signatures_confirmees' => 'Validerade bidrag',
	'titre_statistiques' => 'Statistik för sajten',
	'titre_titre_document' => 'Dokumentets titel:',
	'todo' => 'Att göra',
	'trad_reference' => '(refererad artikel)', # MODIF

	// Z
	'zbug_balise_b_aval' => ': B taggen för sent i loopen',
	'zbug_balise_inexistante' => 'fel @from@: taggen #@balise@ finns inte',
	'zbug_balise_sans_argument' => 'Det saknas ett argument i taggen @balise@',
	'zbug_boucle' => 'loop',
	'zbug_boucle_recursive_undef' => 'recursiv slinga ej definierad', # MODIF
	'zbug_calcul' => 'Omkompilering',
	'zbug_champ_hors_boucle' => 'Fält @champ@ utanför slingan',
	'zbug_champ_hors_motif' => 'Fältet @champ@ utanför slingan med taggen @motif@', # MODIF
	'zbug_code' => 'kod',
	'zbug_critere_inconnu' => 'Kriteriet @critere@ okänt',
	'zbug_distant_interdit' => 'externt data förbjudet', # MODIF
	'zbug_doublon_table_sans_cle_primaire' => 'dubletter i en tabell utan primär nyckel', # MODIF
	'zbug_doublon_table_sans_index' => 'dubbletter i en tabell utan index', # MODIF
	'zbug_erreur_boucle_double' => 'SLINGA@id@: Dubbel definition ', # MODIF
	'zbug_erreur_boucle_fermant' => 'SLINGA@id@: Sista taggen saknas   ', # MODIF
	'zbug_erreur_boucle_syntaxe' => 'Felaktig syntax i slinga (BOUCLE) ', # MODIF
	'zbug_erreur_compilation' => 'Kompileringsfel',
	'zbug_erreur_execution_page' => 'fel då sidan genererades', # MODIF
	'zbug_erreur_filtre' => 'Fel - odefinierat filter: <b>"@filtre@"</b>', # MODIF
	'zbug_erreur_meme_parent' => '{meme_parent} används exklusivt för länkarna (FORUMS) eller (RUBRIQUES)', # MODIF
	'zbug_erreur_squelette' => 'Fel i Mallen',
	'zbug_hors_compilation' => 'Okompilerad',
	'zbug_info_erreur_squelette' => 'ُFel i sajten',
	'zbug_inversion_ordre_inexistant' => 'invertering av en ordningsföljd som inte finns', # MODIF
	'zbug_pagination_sans_critere' => '#PAGINATION tagg utan {pagination} kriteriet, eller använd i en rekursiv slinga', # MODIF
	'zbug_parametres_inclus_incorrects' => 'Felaktiga parametrar för inkludering', # MODIF
	'zbug_profile' => 'Genereringstid: @time@',
	'zbug_resultat' => 'resultat',
	'zbug_serveur_indefini' => 'ingen SQL-server är definierad', # MODIF
	'zbug_statistiques' => 'statistik för SQL-satser ordnade efter tidsåtgång.',
	'zbug_table_inconnue' => 'SQL-tabellen «@table@» okänd',
	'zxml_connus_attributs' => 'kända attribut',
	'zxml_de' => 'från',
	'zxml_inconnu_attribut' => 'Okänt attribut',
	'zxml_inconnu_balise' => 'Okänd tagg',
	'zxml_inconnu_entite' => 'okänd entitet',
	'zxml_inconnu_id' => 'okänt ID',
	'zxml_mais_de' => 'utan från',
	'zxml_non_conforme' => 'följer inte principen',
	'zxml_non_fils' => 'ärver inte från',
	'zxml_nonvide_balise' => 'tagg ej tom',
	'zxml_obligatoire_attribut' => 'obligatoriskt attribut saknas i ',
	'zxml_succession_fils_incorrecte' => 'felaktigt arv',
	'zxml_survoler' => 'för att se de rätta, håll muspekaren ovenför',
	'zxml_valeur_attribut' => 'värde för attribut',
	'zxml_vide_balise' => 'tom tagg',
	'zxml_vu' => 'tidigare sedd',
];
